﻿--[[

Name: MusicStrem Auto Channel
Revision: $Revision: 24634 $
Date: $Date: 2007-01-11 03:28:12 -0500 (Thu, 11 Jan 2007) $
Author(s): benumbed (someone@somewhere.com)
Website: http://www.wowace.com/wiki/MusicStream
Documentation: http://www.wowace.com/wiki/MusicStream
SVN: http://svn.wowace.com/root/trunk/MusicStream
Description: A module to auto play the last channel you were playing on last session.
Dependencies: Ace2, MusicStream

]]--

--- ========================================================= ---
--- Revision
--- ========================================================= ---

local Revision = tonumber(string.sub("$Revision: 24634 $", 12, -3))
if not Revision then
	Revision = "2.0"
end

--- ========================================================= ---
--- Add Locale
--- ========================================================= ---
local L = AceLibrary("AceLocale-2.2"):new("AutoChannel")

L:RegisterTranslations("enUS", function() return {
    ["Auto Channel"] = true,
    ["Toggle saving Channel last played"] = true,
	
    ["Toggle"] = true,
    ["Toggle the Module On and Off"] = true,
} end)

L:RegisterTranslations("koKR", function() return {
	["Auto Channel"] = "자동 채널",
	["Toggle saving Channel last played"] = "마지막 재생 채널을 저장합니다.",

	["Toggle"] = "사용",
	["Toggle the Module On and Off"] = "기능을 사용하거나 사용하지 않습니다.",
} end)

--- ========================================================= ---
--- Register New Module
--- ========================================================= ---

MusicStreamAutoChannel = MusicStream:NewModule("AutoChannel")

--- ========================================================= ---
--- On Initialize
--- ========================================================= ---

function MusicStreamAutoChannel:OnInitialize()
    self.db = MusicStream:AcquireDBNamespace("AutoChannel")
	
    MusicStreamAutoChannel.defaultDB = {
        on = true,
    }
	
	MusicStream:RegisterDefaults("AutoChannel", "profile", opts or MusicStreamAutoChannel.defaultDB or {})
	
    MusicStream:ToggleModuleActive("AutoChannel", self.db.profile.on)
    
	if (self.db.profile.on == true) then
		if (self.db.profile.channel) then
			Channel = self.db.profile.channel;
		end
	end
	
	local bluecolor = "|cFF0099CC"
	local lbluecolor = "|cFF77BBFF"
	
    MusicStream.Options.args.settings.args.AutoChannel = {
        name = L["Auto Channel"],
        desc = L["Toggle saving Channel last played"],
		order = 101,
        type = "group",
        args = {
		     header = {
				type = "header",
				name = bluecolor..L["Auto Channel"].."  |c88888888"..Revision,
				icon = "Interface\\Addons\\MusicStream\\icon.tga",
				iconHeight = 14,
				iconWidth = 14,
				order = 1
            },
			blank = {
       			type = "header",
				order = 2,
			},
            toggle = {
                name = L["Toggle"],
                desc = L["Toggle the Module On and Off"],
				order = 200,
                type = "toggle",
                get = function() return self.db.profile.on end,
                set = function() self.db.profile.on = MusicStream:ToggleModuleActive("AutoChannel") end
            }
        }
    }
end

--- ========================================================= ---
--- On Enable
--- ========================================================= ---

function MusicStreamAutoChannel:OnEnable()
    self:Hook("MusicStream_Play", true)
end

--- ========================================================= ---
--- Reset DB
--- ========================================================= ---

local function copyTable(to, from)
	setmetatable(to, nil)
	for k,v in pairs(from) do
		if type(k) == "table" then
			k = copyTable({}, k)
		end
		if type(v) == "table" then
			v = copyTable({}, v)
		end
		to[k] = v
	end
	setmetatable(to, from)
	return to
end

function MusicStreamAutoChannel:ResetDB()
	copyTable(self.db.profile, MusicStreamAutoChannel.defaultDB)
end

--- ========================================================= ---
--- Functions Hooked
--- ========================================================= ---

function MusicStreamAutoChannel:MusicStream_Play()	
	self.hooks.MusicStream_Play();
	self.db.profile.channel = Channel;
end 