﻿--[[

Name: MusicStrem Channel Alert
Revision: $Revision: 24634 $
Date: $Date: 2007-01-11 03:28:12 -0500 (Thu, 11 Jan 2007) $
Author(s): benumbed (someone@somewhere.com)
Website: http://www.wowace.com/wiki/MusicStream
Documentation: http://www.wowace.com/wiki/MusicStream
SVN: http://svn.wowace.com/root/trunk/MusicStream
Description: A module to alert you when you play music through messages.
Dependencies: Ace2, MusicStream

]]--

--- ========================================================= ---
--- Revision
--- ========================================================= ---

local Revision = tonumber(string.sub("$Revision: 24634 $", 12, -3))
if not Revision then
	Revision = "2.0"
end

--- ========================================================= ---
--- Add Locale
--- ========================================================= ---
local L = AceLibrary("AceLocale-2.2"):new("ChannelAlert")

L:RegisterTranslations("enUS", function() return {
    ["Channel Alert"] = true,
    ["Alert Music being played through messages"] = true,
	
    ["Toggle"] = true,
    ["Toggle the Module On and Off"] = true,
	
	["Show"] = true,
    ["Toggle showing where to display the messages"] = true,
	
	["Show UIMessageFrame"] = true,
    ["Toggles showing message in UI Message Fram."] = true,
	["Show ChatFrame"] = true,
    ["Toggles showing message in Chat Frame"] = true,
} end)

L:RegisterTranslations("koKR", function() return {
	["Channel Alert"] = "채널 알림",
	["Alert Music being played through messages"] = "재생된 음악을 메세지로 알림니다.",

	["Toggle"] = "사용",
	["Toggle the Module On and Off"] = "기능을 사용하거나 사용하지 않습니다.",

	["Show"] = "표시",
	["Toggle showing where to display the messages"] = "메세지를 표시할 곳을 선택합니다.",

	["Show UIMessageFrame"] = "UI메세지창에 표시",
	["Toggles showing message in UI Message Fram."] = "UI 메세지 창에 메세지를 표시합니다.",
	["Show ChatFrame"] = "대화창에 표시",
	["Toggles showing message in Chat Frame"] = "대화창에 메세지를 표시합니다.",
} end)

--- ========================================================= ---
--- Register New Module
--- ========================================================= ---

MusicStreamChannelAlert = MusicStream:NewModule("ChannelAlert")

--- ========================================================= ---
--- On Initialize
--- ========================================================= ---

function MusicStreamChannelAlert:OnInitialize()
    self.db = MusicStream:AcquireDBNamespace("ChannelAlert")

    MusicStreamChannelAlert.defaultDB = {
        on = true,
		show = {true, false},
    }
	
	MusicStream:RegisterDefaults("ChannelAlert", "profile", opts or MusicStreamChannelAlert.defaultDB or {})
	
    MusicStream:ToggleModuleActive("ChannelAlert", self.db.profile.on)
    
	local bluecolor = "|cFF0099CC"
	local lbluecolor = "|cFF77BBFF"
	
    MusicStream.Options.args.settings.args.ChannelAlert = {
        name = L["Channel Alert"],
        desc = L["Alert Music being played through messages"],
		order = 102,
        type = "group",
        args = {
			header = {
				type = "header",
				name = bluecolor..L["Channel Alert"].."  |c88888888"..Revision,
				icon = "Interface\\Addons\\MusicStream\\icon.tga",
				iconHeight = 14,
				iconWidth = 14,
				order = 1
            },
			blank = {
       			type = "header",
				order = 2,
			},
			show = {
                name = L["Show"],
                desc = L["Toggle showing where to display the messages"],
				order = 100,
                type = "group",
                args = {
                    chatframe = {
                        name = string.format(L["Show ChatFrame"], 2),
                        desc = string.format(L["Toggles showing message in Chat Frame"], 2),
						order = 100,
                        type = "toggle",
                        get = function() return self.db.profile.show[2] end,
                        set = function(v) self.db.profile.show[2] = v end
                    },
					uimessageframe = {
                        name = string.format(L["Show UIMessageFrame"], 1),
                        desc = string.format(L["Toggle the Module On and Off"], 1),
						order = 105,
                        type = "toggle",
                        get = function() return self.db.profile.show[1] end,
                        set = function(v) self.db.profile.show[1] = v end
                    },
                },
            },
			blank = {
				type = 'header',
				order = 195,
			},
             toggle = {
                name = L["Toggle"],
                desc = L["Toggle the Module On and Off"],
                type = "toggle",
                order = 200,
                get = function() return self.db.profile.on end,
                set = function() self.db.profile.on = MusicStream:ToggleModuleActive("ChannelAlert") end
            }
        }
    }
end

--- ========================================================= ---
--- Reset DB
--- ========================================================= ---

local function copyTable(to, from)
	setmetatable(to, nil)
	for k,v in pairs(from) do
		if type(k) == "table" then
			k = copyTable({}, k)
		end
		if type(v) == "table" then
			v = copyTable({}, v)
		end
		to[k] = v
	end
	setmetatable(to, from)
	return to
end

function MusicStreamChannelAlert:ResetDB()
	copyTable(self.db.profile, MusicStreamChannelAlert.defaultDB)
end

--- ========================================================= ---
--- Alert
--- ========================================================= ---

function MusicStreamChannelAlert:ChannelAlert(txt)
	if (self.db.profile.on == true) then
		if (self.db.profile.show[1] == true) then
			if (IsAddOnLoaded("SCT")) then
				SCT:DisplayCustomEvent(txt,{r=1,g=1,b=1}, iscrit);
			else
				UIErrorsFrame:AddMessage(txt,1, 1, 1, 1,10);
			end
		end
		if (self.db.profile.show[2] == true) then
			DEFAULT_CHAT_FRAME:AddMessage(txt);
		end
	end
end

--- ========================================================= ---
--- On Enable (set hook)
--- ========================================================= ---

function MusicStreamChannelAlert:OnEnable()
    self:Hook("MusicStream_Play", true)
	self:Hook("MusicStream_Stop", true)
end

--- ========================================================= ---
--- Functions Hooked
--- ========================================================= ---

function MusicStreamChannelAlert:MusicStream_Play()
	self.hooks.MusicStream_Play();
	MusicStreamChannelAlert:ChannelAlert("CH"..Channel.." - "..ChannelNowLabel.." - ");
end

function MusicStreamChannelAlert:MusicStream_Stop()
	self.hooks.MusicStream_Stop();
	MusicStreamChannelAlert:ChannelAlert("Music Stopped");
end 