﻿--[[

Name: MusicStrem Import Channel
Revision: $Revision: 24634 $
Date: $Date: 2007-01-11 03:28:12 -0500 (Thu, 11 Jan 2007) $
Author(s): benumbed (someone@somewhere.com)
Website: http://www.wowace.com/wiki/MusicStream
Documentation: http://www.wowace.com/wiki/MusicStream
SVN: http://svn.wowace.com/root/trunk/MusicStream
Description: A module to import a channel into the database.
Dependencies: Ace2, MusicStream

]]--

--- ========================================================= ---
--- Revision
--- ========================================================= ---

local Revision = tonumber(string.sub("$Revision: 24634 $", 12, -3))
if not Revision then
	Revision = "2.0"
end

--- ========================================================= ---
--- Add Locale
--- ========================================================= ---
local L = AceLibrary("AceLocale-2.2"):new("ChannelImport")

L:RegisterTranslations("enUS", function() return {
    ["Import Channel"] = true,
    ["Import a Custom Channel into the Database"] = true,
	["Import"] = true,
    ["Import a channel into the database."] = true,
    ["Toggle"] = true,
    ["Toggle the module on and off."] = true,
    ["Accept"] = true,
	
	["Import Channel"] = true,
	["Channel Name:"] = true,
	["Address:"] = true,
	["Genre:"] = true,
	
	["Reset"] = true,
	["Test"] = true,
	["Accept"] = true,
	["Cancel"] = true,
} end)

L:RegisterTranslations("koKR", function() return {
	["Import Channel"] = "채널 추가",
	["Import a Custom Channel into the Database"] = "데이터베이스에 사용자 지정 채널을 추가합니다.",
	["Import"] = "추가",
	["Import a channel into the database."] = "데이터베이스에 채널을 추가합니다.",
	["Toggle"] = "사용",
	["Toggle the Module On and Off"] = "기능을 사용하거나 사용하지 않습니다.",
	["Accept"] = "확인",

	["Import Channel"] = "채널 추가",
	["Channel Name:"] = "채널명:",
	["Address:"] = "주소:",
	["Genre:"] = "장르:",

	["Reset"] = "초기화",
	["Test"] = "테스트",
	["Accept"] = "확인",
	["Cancel"] = "취소",
} end)

MSIC_IMPORT_CHANNEL = L["Import Channel"]
MSIC_CHANNEL_NAME = L["Channel Name:"]
MSIC_ADDRESS = L["Address:"]
MSIC_GENRE = L["Genre:"]

MSIC_RESET = L["Reset"]
MSIC_TEST = L["Test"]
MSIC_ACCEPT = L["Accept"]
MSIC_CANCEL = L["Cancel"]

--- ========================================================= ---
--- Set Genre List
--- ========================================================= ---

local GENRE_SEVENTYS = 1;
local GENRE_EIGHTYS = 2;
local GENRE_NINETYS = 3;
local GENRE_COUNTRY = 4;
local GENRE_POP = 5;
local GENRE_RAP = 6;
local GENRE_ROCK = 7;
local GENRE_TECHNO = 8;
local GENRE_JAZZ = 9;
local GENRE_CLASSICAL = 10;
local GENRE_COMEDY = 11;
local GENRE_TALK = 12;

local MUSICSTREAM_GENRE_LIST = {
	{ name = "70s", value = GENRE_SEVENTYS },
	{ name = "80s", value = GENRE_EIGHTYS },
	{ name = "90s", value = GENRE_NINETYS },
	{ name = "Country", value = GENRE_COUNTRY },
	{ name = "Pop", value = GENRE_POP },
	{ name = "Rap", value = GENRE_RAP },
	{ name = "Rock", value = GENRE_ROCK },
	{ name = "Techno", value = GENRE_TECHNO },
	{ name = "Jazz", value = GENRE_JAZZ },
	{ name = "Classical", value = GENRE_CLASSICAL },
	{ name = "Comedy", value = GENRE_COMEDY },
	{ name = "Talk", value = GENRE_TALK },
};

--- ========================================================= ---
--- Register New Module
--- ========================================================= ---

MusicStreamChannelImport = MusicStream:NewModule("ChannelImport")

--- ========================================================= ---
--- On Initialize
--- ========================================================= ---

function MusicStreamChannelImport:OnInitialize()
    self.db = MusicStream:AcquireDBNamespace("ChannelImport")
	
	MusicStreamChannelImport.defaultDB = {
    }
	
	MusicStream:RegisterDefaults("ChannelImport", "profile", opts or MusicStreamChannelImport.defaultDB or {})
    
	local bluecolor = "|cFF0099CC"
	local lbluecolor = "|cFF77BBFF"
	
    MusicStream.Options.args.settings.args.ChannelImport = {
        name = L["Import Channel"],
        desc = L["Import a Custom Channel into the Database"],
		order = 201,
        type = "group",
        args = {
			header = {
				type = "header",
				name = bluecolor..L["Import Channel"].."  |c88888888"..Revision,
				icon = "Interface\\Addons\\MusicStream\\icon.tga",
				iconHeight = 14,
				iconWidth = 14,
				order = 1
            },
			blank = {
       			type = "header",
				order = 2,
			},
			 import = {
             	name = L["Import"],
                desc = L["Import a channel into the database."],
				order = 100,
                type = "execute",
    			func = function() self.ImportPopup() end,
             },
        }
    }
end

--- ========================================================= ---
--- Reset DB
--- ========================================================= ---

local function copyTable(to, from)
	setmetatable(to, nil)
	for k,v in pairs(from) do
		if type(k) == "table" then
			k = copyTable({}, k)
		end
		if type(v) == "table" then
			v = copyTable({}, v)
		end
		to[k] = v
	end
	setmetatable(to, from)
	return to
end

function MusicStreamChannelImport:ResetDB()
	copyTable(self.db.profile, MusicStreamChannelImport.defaultDB)
end

--- ========================================================= ---
--- Import Popup
--- ========================================================= ---

function MusicStreamChannelImport:ImportPopup()
	MusicStream_Import:Show();
end

--- ========================================================= ---
--- Import Reset button
--- ========================================================= ---

function MusicStreamImport_Reset()
	MusicStream_Import_ResetValues();
end

--- ========================================================= ---
--- Import Test button
--- ========================================================= ---

function MusicStreamImport_Test()
	MusicStream_Import_SaveValues();
end

--- ========================================================= ---
--- Import Accept Button
--- ========================================================= ---

function MusicStreamImport_Accept()
	MusicStream_Import_SaveValues();
	MusicStream_Import:Hide();
	MusicStreamChannelImport:SavetoDB();
end

--- ========================================================= ---
--- Import Cancel button
--- ========================================================= ---

function MusicStreamImport_Cancel()
	MusicStream_Import:Hide();
end

--- ========================================================= ---
--- Import Genre Dropdown
--- ========================================================= ---

function MusicStream_Genre_OnLoad()
	UIDropDownMenu_SetWidth(90);
	UIDropDownMenu_SetButtonWidth(24);
	UIDropDownMenu_JustifyText("LEFT", MusicStream_Import_Genre_DropDown);
end

function MusicStream_Genre_OnClick()
	UIDropDownMenu_SetSelectedID(MusicStream_Import_Genre_DropDown, this:GetID());
end

local function MusicStream_UIDropDownMenu_SetSelectedID(frame, id, names)
	UIDropDownMenu_SetSelectedID(frame, id);
	if( not frame ) then
		frame = this;
	end
	UIDropDownMenu_SetText(names[id].name, frame);
end

function MusicStream_Import_LoadValues()
	UIDropDownMenu_Initialize(MusicStream_Import_Genre_DropDown, MusicStream_Genre_Initialize);
	if not(ChannelImportGenreN) then
		MusicStream_UIDropDownMenu_SetSelectedID(MusicStream_Import_Genre_DropDown, 1, MUSICSTREAM_GENRE_LIST);
	else
		MusicStream_UIDropDownMenu_SetSelectedID(MusicStream_Import_Genre_DropDown, ChannelImportGenreN, MUSICSTREAM_GENRE_LIST);
	end
end

function MusicStream_Genre_Initialize()
	local info;
	for i = 1, #MUSICSTREAM_GENRE_LIST, 1 do
		info = { };
		info.text = MUSICSTREAM_GENRE_LIST[i].name;
		info.func = MusicStream_Genre_OnClick;
		UIDropDownMenu_AddButton(info);
	end
end

--- ========================================================= ---
--- Import Reset
--- ========================================================= ---

function MusicStream_Import_ResetValues()
	
	field = getglobal("MusicStream_Import_ChannelName_EditBox");
	field:SetText("");

	field = getglobal("MusicStream_Import_Address_EditBox");
	field:SetText("");

	MusicStream_UIDropDownMenu_SetSelectedID(MusicStream_Import_Genre_DropDown, 1, MUSICSTREAM_GENRE_LIST);

end

--- ========================================================= ---
--- Import Save
--- ========================================================= ---

function MusicStream_Import_SaveValues()
	
	field = getglobal("MusicStream_Import_ChannelName_EditBox");
	value = field:GetText();
	if( value == "" ) then
		value = "Custom Channel";
	end
	
	ChannelImportName = value;

	field = getglobal("MusicStream_Import_Address_EditBox");
	value = field:GetText();
	if( value == "" ) then
		value = "http://noaddress";
	end
	
	ChannelImportAddress = value;

	value = UIDropDownMenu_GetSelectedID(MusicStream_Import_Genre_DropDown);
	
	if (value == 1) then
		ChannelImportGenre = "Seventys";
	end

	if (value == 2) then
		ChannelImportGenre = "Eightys";
	end
	
	if (value == 3) then
		ChannelImportGenre = "Ninetys";
	end
	
	if (value == 4) then
		ChannelImportGenre = "Country";
	end

	if (value == 5) then
		ChannelImportGenre = "Pop";
	end
	
	if (value == 6) then
		ChannelImportGenre = "Rap";
	end

	if (value == 7) then
		ChannelImportGenre = "Rock";
	end
	
	if (value == 8) then
		ChannelImportGenre = "Techno";
	end
	
	if (value == 9) then
		ChannelImportGenre = "Jazz";
	end

	if (value == 10) then
		ChannelImportGenre = "Classical";
	end
	
	if (value == 11) then
		ChannelImportGenre = "Comedy";
	end

	if (value == 12) then
		ChannelImportGenre = "Talk";
	end

	ChannelImportGenreN = value;
	
	MusicStreamChannelAlert:ChannelAlert("[Now Testing] "..ChannelImportGenre.." - "..ChannelImportName.." - ("..ChannelImportAddress..")")
	PlayMusic(ChannelImportAddress);
		
	ChannelNowLabel = ChannelImportName;
	ChannelNowAddress = ChannelImportAddress;

end

--- ========================================================= ---
--- Import Save into DB
--- ========================================================= ---

function MusicStreamChannelImport:SavetoDB()
	TotalChannels = TotalChannels + 1;
	MusicStreamChannels.db.profile.channels[TotalChannels] = {};
	MusicStreamChannels.db.profile.channels[TotalChannels]["channel"] = TotalChannels;
	MusicStreamChannels.db.profile.channels[TotalChannels]["title"] = ChannelImportName;
	MusicStreamChannels.db.profile.channels[TotalChannels]["address"] = ChannelImportAddress;
	MusicStreamChannels.db.profile.channels[TotalChannels]["genre"] = ChannelImportGenre;
	MusicStreamChannels.db.profile.channels[TotalChannels]["skip"] = false;
	
	if MusicStreamSkipChannel then
		MusicStreamSkipChannel:BuildSkipped();
	end
	
	if MusicStreamRemoveChannel then
		MusicStreamRemoveChannel:BuildRemoved();
	end
	
	MusicStreamChannels:BuildChannels();
	MusicStreamChannels:GetMusic();
end