--[[

Name: MusicStrem Player Settings
Revision: $Revision: 24634 $
Date: $Date: 2007-01-11 03:28:12 -0500 (Thu, 11 Jan 2007) $
Author(s): benumbed (someone@somewhere.com)
Website: http://www.wowace.com/wiki/MusicStream
Documentation: http://www.wowace.com/wiki/MusicStream
SVN: http://svn.wowace.com/root/trunk/MusicStream
Description: A module to control various Player settings.
Dependencies: Ace2, MusicStream

]]--

--- ========================================================= ---
--- Revision
--- ========================================================= ---

local Revision = tonumber(string.sub("$Revision: 24634 $", 12, -3))
if not Revision then
	Revision = "2.0"
end

--- ========================================================= ---
--- Add Locale
--- ========================================================= ---
local L = AceLibrary("AceLocale-2.2"):new("PlayerSettings")

L:RegisterTranslations("enUS", function() return {
	["Player Settings"] = true,
	["Apperance"] = true,
	["Change the Apperance of the Player"] = true,
	["Backdrop Color"] = true,
	["Change the Player's Backdrop Color"] = true,
	["Border Color"] = true,
	["Change the Player's Border Color"] = true,
	["Channel Color"] = true,
	["Change the Player's Channel Color"] = true,
	["Player Scale"] = true,
	["Set the Player's Scale"] = true,
	["Player Lock"] = true,
	["Toggle the Player's Lock Status"] = true,
	["Toggle Player"] = true,
	["Toggle the Player's Frame"] = true,
} end)

L:RegisterTranslations("koKR", function() return {
	["Player Settings"] = "플레이어 설정",
	["Apperance"] = "외형",
	["Change the Apperance of the Player"] = "플레이어의 외형을 변경합니다.",
	["Backdrop Color"] = "배경 색상",
	["Change the Player's Backdrop Color"] = "플레이어의 배경 색상을 변경합니다.",
	["Border Color"] = "테두리 색상",
	["Change the Player's Border Color"] = "플레이어의 테두리 색상을 변경합니다.",
	["Channel Color"] = "채널 색상",
	["Change the Player's Channel Color"] = "플레이어의 채널 색상을 변경합니다.",
	["Player Scale"] = "플레이어 크기",
	["Set the Player's Scale"] = "플레이어의 크기를 설정합니다.",
	["Player Lock"] = "플레이어 고정",
	["Toggle the Player's Lock Status"] = "플레이어의 고정 상태를 전환합니다.",
	["Toggle Player"] = "플레이어 전환",
	["Toggle the Player's Frame"] = "플레이어의 창을 전환합니다.",
} end)

--- ========================================================= ---
--- Register New Module
--- ========================================================= ---

MusicStreamPlayerSettings = MusicStream:NewModule("PlayerSettings")

--- ========================================================= ---
--- On Initialize
--- ========================================================= ---

function MusicStreamPlayerSettings:OnInitialize()
    self.db = MusicStream:AcquireDBNamespace("PlayerSettings")
	
	MusicStreamPlayerSettings.defaultDB = {
		playerscale = 1,
		lock = false,
		show = true,
		
		backdropcolor = {
            r = 0.10,
            g = 0.10,
            b = 0.10,
            a = 1.00,
        },
		bordercolor = {
            r = 0.90,
            g = 0.90,
            b = 0.90,
            a = 1.00,
        },
		channelcolor = {
            r = 0.90,
            g = 0.90,
            b = 0.90,
            a = 1.00,
        },
    }
	
	MusicStream:RegisterDefaults("PlayerSettings", "profile", opts or MusicStreamPlayerSettings.defaultDB or {})
    
	local bluecolor = "|cFF0099CC"
	local lbluecolor = "|cFF77BBFF"
	
	MusicStream.Options.args.settings.args.PlayerSettingsBlank = {
       	type = "header",
		order = 299,
	}
	
	MusicStream.Options.args.settings.args.PlayerSettings = {
		name = lbluecolor..L["Player Settings"],
		icon = "Interface\\GossipFrame\\BinderGossipIcon",
       	type = "header",
		order = 300,
	}
	
	MusicStream.Options.args.settings.args.PlayerSettingsApperance = {
		name = L["Apperance"],
		desc = L["Change the Apperance of the Player"],
       	type = "group",
		order = 301,
		args = {
			header = {
				type = "header",
				name = bluecolor..L["Player Settings"].."  |c88888888"..Revision,
				icon = "Interface\\Addons\\MusicStream\\icon.tga",
				iconHeight = 14,
				iconWidth = 14,
				order = 1
            },
			blank = {
       			type = "header",
				order = 2,
			},
			backdropcolor = {
				name = L["Backdrop Color"],
				desc = L["Change the Player's Backdrop Color"],
				order = 100,
    			type = 'color',
    			get = function() return 
					self.db.profile.backdropcolor.r,
                	self.db.profile.backdropcolor.g,
                	self.db.profile.backdropcolor.b,
					self.db.profile.backdropcolor.a
    			end,
    			set = function(r, g, b, a)
                	self.db.profile.backdropcolor.r,
                	self.db.profile.backdropcolor.g,
                	self.db.profile.backdropcolor.b,
					self.db.profile.backdropcolor.a
					= r, g, b, a;
					MusicStreamPlayerSettings:SetBackdropColor();
    			end,
    			hasAlpha = true
			},
			bordercolor = {
				name = L["Border Color"],
				desc = L["Change the Player's Border Color"],
				order = 200,
    			type = 'color',
    			get = function() return 
					self.db.profile.bordercolor.r,
                	self.db.profile.bordercolor.g,
                	self.db.profile.bordercolor.b,
					self.db.profile.bordercolor.a
    			end,
    			set = function(r, g, b, a)
                	self.db.profile.bordercolor.r,
                	self.db.profile.bordercolor.g,
                	self.db.profile.bordercolor.b,
					self.db.profile.bordercolor.a
					= r, g, b, a;
					MusicStreamPlayerSettings:SetBorderColor();
    			end,
    			hasAlpha = true
			},
			channelcolor = {
				name = L["Channel Color"],
				desc = L["Change the Player's Channel Color"],
				order = 300,
    			type = 'color',
    			get = function() return 
					self.db.profile.channelcolor.r,
                	self.db.profile.channelcolor.g,
                	self.db.profile.channelcolor.b,
					self.db.profile.channelcolor.a
    			end,
    			set = function(r, g, b, a)
                	self.db.profile.channelcolor.r,
                	self.db.profile.channelcolor.g,
                	self.db.profile.channelcolor.b,
					self.db.profile.channelcolor.a
					= r, g, b, a;
					MusicStreamPlayerSettings:SetChannelColor();
    			end,
    			hasAlpha = true
			},
		}
	}
		
	MusicStream.Options.args.settings.args.PlayerSettingsScale = {
		name = L["Player Scale"],
		desc = L["Set the Player's Scale"],
		order = 302,
		type = 'range',
		min  = 0.1,
		max  = 1.0,
		step = 0.05,
		set  = function(scale) self.db.profile.playerscale = scale;  MusicStreamPlayerSettings:SetScale(); end,
		get  = function() return self.db.profile.playerscale end,
	}
	
	MusicStream.Options.args.settings.args.PlayerSettingsLock = {
        name = L["Player Lock"],
        desc = L["Toggle the Player's Lock Status"],
		order = 303,
        type = "toggle",
        get = function() return self.db.profile.lock end,
        set = function() self.db.profile.lock = not self.db.profile.lock end
	}
	
	MusicStream.Options.args.PlayerToggle = {
        name = L["Toggle Player"],
        desc = L["Toggle the Player's Frame"],
		order = 1000,
        type = "execute",
		func = function() self:TogglePlayer() end,
	}

end

--- ========================================================= ---
--- On Enable
--- ========================================================= ---

function MusicStreamPlayerSettings:OnEnable()
	MusicStreamPlayer:SetBackdropColor(self.db.profile.backdropcolor.r, self.db.profile.backdropcolor.g, self.db.profile.backdropcolor.b, self.db.profile.backdropcolor.a);
	MusicStreamPlayer:SetBackdropBorderColor(self.db.profile.bordercolor.r, self.db.profile.bordercolor.g, self.db.profile.bordercolor.b, self.db.profile.bordercolor.a);
	MSNowPlaying:SetTextColor(self.db.profile.channelcolor.r, self.db.profile.channelcolor.g, self.db.profile.channelcolor.b, self.db.profile.channelcolor.a);
	MusicStreamPlayer:SetScale(self.db.profile.playerscale);
	
	if not self.db.profile.show then
		MusicStreamPlayer:Hide();
	else
		MusicStreamPlayer:Show();
	end
end

--- ========================================================= ---
--- Reset DB
--- ========================================================= ---

local function copyTable(to, from)
	setmetatable(to, nil)
	for k,v in pairs(from) do
		if type(k) == "table" then
			k = copyTable({}, k)
		end
		if type(v) == "table" then
			v = copyTable({}, v)
		end
		to[k] = v
	end
	setmetatable(to, from)
	return to
end

function MusicStreamPlayerSettings:ResetDB()
	copyTable(self.db.profile, MusicStreamPlayerSettings.defaultDB)
end

--- ========================================================= ---
--- Set Player BackdropColor
--- ========================================================= ---

function MusicStreamPlayerSettings:SetBackdropColor()
	MusicStreamPlayer:SetBackdropColor(self.db.profile.backdropcolor.r, self.db.profile.backdropcolor.g, self.db.profile.backdropcolor.b, self.db.profile.backdropcolor.a);
end

--- ========================================================= ---
--- Set Player BorderColor
--- ========================================================= ---

function MusicStreamPlayerSettings:SetBorderColor()
	MusicStreamPlayer:SetBackdropBorderColor(self.db.profile.bordercolor.r, self.db.profile.bordercolor.g, self.db.profile.bordercolor.b, self.db.profile.bordercolor.a);
end

--- ========================================================= ---
--- Set Player ChannelColor
--- ========================================================= ---

function MusicStreamPlayerSettings:SetChannelColor()
	MSNowPlaying:SetTextColor(self.db.profile.channelcolor.r, self.db.profile.channelcolor.g, self.db.profile.channelcolor.b, self.db.profile.channelcolor.a);
end

--- ========================================================= ---
--- Set Player Scale
--- ========================================================= ---

function MusicStreamPlayerSettings:SetScale()
	MusicStreamPlayer:SetScale(self.db.profile.playerscale);
end

--- ========================================================= ---
--- Check Player Lock Status
--- ========================================================= ---

function MusicStreamPlayerSettings:CheckLock()
	if not self.db.profile.lock then
		if(arg1 == "LeftButton") then
			MusicStreamPlayer:StartMoving();
		end
	end
end

--- ========================================================= ---
--- Toggle Player
--- ========================================================= ---

function MusicStreamPlayerSettings:TogglePlayer()
	if (MusicStreamPlayer:IsVisible()) then
		MusicStreamPlayer:Hide();
	else
		MusicStreamPlayer:Show();
	end
	self.db.profile.show = not self.db.profile.show
end

--- ========================================================= ---
--- MusicStream Player Music Mute Check
--- ========================================================= ---

function MusicStreamPlayerSettings:GetEnableMusic()
	local Volume = getglobal(this:GetName());
	if GetCVar("EnableMusic") == "1" then
		Volume:SetNormalTexture("Interface\\AddOns\\MusicStream\\images\\PlayerVolume_UnMute.tga")
		Volume:SetPushedTexture("Interface\\AddOns\\MusicStream\\images\\PlayerVolume_UnMute_Pushed.tga")
		Volume:SetHighlightTexture("Interface\\AddOns\\MusicStream\\images\\PlayerVolume_UnMute_Pushed.tga", "BLEND")
	else
		Volume:SetNormalTexture("Interface\\AddOns\\MusicStream\\images\\PlayerVolume_Mute.tga")
		Volume:SetPushedTexture("Interface\\AddOns\\MusicStream\\images\\PlayerVolume_Mute_Pushed.tga")
		Volume:SetHighlightTexture("Interface\\AddOns\\MusicStream\\images\\PlayerVolume_Mute_Pushed.tga", "BLEND")
	end
end

--- ========================================================= ---
--- MusicStream Player Music Toggle
--- ========================================================= ---

function MusicStreamPlayerSettings:ToggleEnableMusic()
	SetCVar("EnableMusic", GetCVar("EnableMusic") == "1" and 0 or 1)
end