﻿--[[

Name: MusicStrem Skip Channels
Revision: $Revision: 24634 $
Date: $Date: 2007-01-11 03:28:12 -0500 (Thu, 11 Jan 2007) $
Author(s): benumbed (someone@somewhere.com)
Website: http://www.wowace.com/wiki/MusicStream
Documentation: http://www.wowace.com/wiki/MusicStream
SVN: http://svn.wowace.com/root/trunk/MusicStream
Description: A module to select channels to skip.
Dependencies: Ace2, MusicStream

]]--

--- ========================================================= ---
--- Revision
--- ========================================================= ---

local Revision = tonumber(string.sub("$Revision: 24634 $", 12, -3))
if not Revision then
	Revision = "2.0"
end

--- ========================================================= ---
--- Add Locale
--- ========================================================= ---
local L = AceLibrary("AceLocale-2.2"):new("SkipChannel")

L:RegisterTranslations("enUS", function() return {
    ["Skip Channels"] = true,
    ["Add a Channel to the Skip List"] = true,
	
	["Pop"] = true,
	["Skip Pop Channels"] = true,
	["Rap"] = true,
	["Skip Rap Channels"] = true,
	["Rock"] = true,
	["Skip Rock Channels"] = true,
	["Country"] = true,
	["Skip Country Channels"] = true,
	["90s"] = true,
	["Skip 90s Channels"] = true,
	["80s"] = true,
	["Skip 80s Channels"] = true,
	["70s"] = true,
	["Skip 70s Channels"] = true,
	["Techno"] = true,
	["Skip Techno Channels"] = true,
	["Jazz"] = true,
	["Skip Jazz Channels"] = true,
	["Classical"] = true,
	["Skip Classical Channels"] = true,
	["Comedy"] = true,
	["Skip Comedy Channels"] = true,
	["Talk"] = true,
	["Skip Talk Channels"] = true,
} end)

L:RegisterTranslations("koKR", function() return {
	["Skip Channels"] = "채널 제외",
	["Add a Channel to the Skip List"] = "제외 목록에 채널을 추가합니다.",

	["Pop"] = "팝",
	["Skip Pop Channels"] = "팝 채널을 건너뜁니다.",
	["Rap"] = "랩",
	["Skip Rap Channels"] = "랩 채널을 건너뜁니다.",
	["Rock"] = "락",
	["Skip Rock Channels"] = "락 채널을 건너뜁니다.",
	["Country"] = "컨트리",
	["Skip Country Channels"] = "컨트리 채널을 건너뜁니다.",
	["90s"] = "90년대",
	["Skip 90s Channels"] = "90년대 채널을 건너뜁니다.",
	["80s"] = "80년대",
	["Skip 80s Channels"] = "80년대 채널을 건너뜁니다.",
	["70s"] = "70년대",
	["Skip 70s Channels"] = "70년대 채널을 건너뜁니다.",
	["Techno"] = "테크노",
	["Skip Techno Channels"] = "테크노 채널을 건너뜁니다.",
	["Jazz"] = "재즈",
	["Skip Jazz Channels"] = "재즈 채널을 건너뜁니다.",
	["Classical"] = "클래식",
	["Skip Classical Channels"] = "클래식 채널을 건너뜁니다.",
	["Comedy"] = "코미디",
	["Skip Comedy Channels"] = "코미디 채널을 건너뜁니다.",
	["Talk"] = "토크",
	["Skip Talk Channels"] = "토크 채널을 건너뜁니다.",
} end)

--- ========================================================= ---
--- Register New Module
--- ========================================================= ---

MusicStreamSkipChannel = MusicStream:NewModule("SkipChannel")

--- ========================================================= ---
--- On Initialize
--- ========================================================= ---

function MusicStreamSkipChannel:OnInitialize()
    self.db = MusicStream:AcquireDBNamespace("SkipChannel")
	
	MusicStreamSkipChannel.defaultDB = {
    }
	
	MusicStream:RegisterDefaults("SkipChannel", "profile", opts or MusicStreamSkipChannel.defaultDB or {})
	
	MSSkipChannel = self.db.profile.on;
	    
	local bluecolor = "|cFF0099CC"
	local lbluecolor = "|cFF77BBFF"
	
    MusicStream.Options.args.settings.args.SkipChannel = {
        name = L["Skip Channels"],
        desc = L["Add a Channel to the Skip List"],
		order = 202,
        type = "group",
        args = {
			header = {
				type = "header",
				name = bluecolor..L["Skip Channels"].."  |c88888888"..Revision,
				icon = "Interface\\Addons\\MusicStream\\icon.tga",
				iconHeight = 14,
				iconWidth = 14,
				order = 1
            },
			blank = {
       			type = "header",
				order = 2,
			},
			Pop = {
                name = L["Pop"],
                desc = L["Skip Pop Channels"],
                type = "group",
                order = 100,
                args = {
                },
			},
			Rap = {
                name = L["Rap"],
                desc = L["Skip Rap Channels"],
                type = "group",
                order = 100,
                args = {
                },
			},
			Rock = {
                name = L["Rock"],
                desc = L["Skip Rock Channels"],
                type = "group",
                order = 100,
                args = {
                },
			},
			Country = {
                name = L["Country"],
                desc = L["Skip Country Channels"],
                type = "group",
                order = 100,
                args = {
                },
			},
			Ninetys = {
                name = L["90s"],
                desc = L["Skip 90s Channels"],
                type = "group",
                order = 100,
                args = {
                },
			},
			Eightys = {
                name = L["80s"],
                desc = L["Skip 80s Channels"],
                type = "group",
                order = 100,
                args = {
                },
			},
			Seventys = {
                name = L["70s"],
                desc = L["Skip 70s Channels"],
                type = "group",
                order = 100,
                args = {
                },
			},
			Techno = {
                name = L["Techno"],
                desc = L["Skip Techno Channels"],
                type = "group",
                order = 100,
                args = {
                },
			},
			Jazz = {
                name = L["Jazz"],
                desc = L["Skip Jazz Channels"],
                type = "group",
                order = 100,
                args = {
                },
			},
			Classical = {
                name = L["Classical"],
                desc = L["Skip Classical Channels"],
                type = "group",
                order = 100,
                args = {
                },
			},
			Comedy = {
                name = L["Comedy"],
                desc = L["Skip Comedy Channels"],
                type = "group",
                order = 100,
                args = {
                },
			},
			Talk = {
                name = L["Talk"],
                desc = L["Skip Talk Channels"],
                type = "group",
                order = 100,
                args = {
                },
			},
        }
    }
	
	MusicStreamSkipChannel:BuildSkipped();
	
end

--- ========================================================= ---
--- Reset DB
--- ========================================================= ---

local function copyTable(to, from)
	setmetatable(to, nil)
	for k,v in pairs(from) do
		if type(k) == "table" then
			k = copyTable({}, k)
		end
		if type(v) == "table" then
			v = copyTable({}, v)
		end
		to[k] = v
	end
	setmetatable(to, from)
	return to
end

function MusicStreamSkipChannel:ResetDB()
	copyTable(self.db.profile, MusicStreamSkipChannel.defaultDB)
	MusicStreamSkipChannel:BuildSkipped();
end

--- ========================================================= ---
--- Build Skip Channel List
--- ========================================================= ---

function MusicStreamSkipChannel:BuildSkipped()
	for i,data in ipairs(MusicStreamChannels.db.profile.channels) do
		genre = MusicStreamChannels.db.profile.channels[i].genre;
	
		if (genre == "70s") then
			genre = "Seventys";
		end
		if (genre == "80s") then
			genre = "Eightys";
		end
		if (genre == "90s") then
			genre = "Ninetys";
		end
		
		MusicStream.Options.args.settings.args.SkipChannel.args[genre].args = { }
	end
	
	for i,data in pairs(MusicStreamChannels.db.profile.channels) do
		if not MusicStreamChannels.db.profile.channels[i].removed then
			genre = MusicStreamChannels.db.profile.channels[i].genre;
		
			if (genre == "70s") then
				genre = "Seventys";
			end
			if (genre == "80s") then
				genre = "Eightys";
			end
			if (genre == "90s") then
				genre = "Ninetys";
			end
	
			MusicStream.Options.args.settings.args.SkipChannel.args[genre].args[i] = {
				name = MusicStreamChannels.db.profile.channels[i].title,
				desc = MusicStreamChannels.db.profile.channels[i].address,
				type = 'toggle',
				order = i,
				get = function()
					return MusicStreamSkipChannel:IsSkippingChannel(i)
				end,
				set = function(value)
					return MusicStreamSkipChannel:ToggleSkipChannel(i, value)
				end,
			}
		end
	end
end

--- ========================================================= ---
--- Get Skip Channels
--- ========================================================= ---

function MusicStreamSkipChannel:IsSkippingChannel(channel)
	return MusicStreamChannels.db.profile.channels[channel].skip
end

--- ========================================================= ---
--- Toggle Skip Channels
--- ========================================================= ---

function MusicStreamSkipChannel:ToggleSkipChannel(channel, value)
	if value == nil then
		value = not MusicStreamChannels.db.profile.channels[channel].skip
	end
	MusicStreamChannels.db.profile.channels[channel].skip = value
	
	MusicStreamChannels:GetMusic();
end