﻿--[[

Name: MusicStrem Tell Channel
Revision: $Revision: 24634 $
Date: $Date: 2007-01-11 03:28:12 -0500 (Thu, 11 Jan 2007) $
Author(s): benumbed (someone@somewhere.com)
Website: http://www.wowace.com/wiki/MusicStream
Documentation: http://www.wowace.com/wiki/MusicStream
SVN: http://svn.wowace.com/root/trunk/MusicStream
Description: A module to tell someone the channel you are currently playing.
Dependencies: Ace2, MusicStream

]]--

--- ========================================================= ---
--- Revision
--- ========================================================= ---

local Revision = tonumber(string.sub("$Revision: 24634 $", 12, -3))
if not Revision then
	Revision = "2.0"
end

--- ========================================================= ---
--- Add Locale
--- ========================================================= ---
local L = AceLibrary("AceLocale-2.2"):new("TellChannel")

L:RegisterTranslations("enUS", function() return {
    ["Tell Channel"] = true,
    ["Tell someone what Channel you are listening to"] = true,
	
	["Guild"] = true,
    ["Tell -Guild- what you are currently playing."] = true,	

} end)

L:RegisterTranslations("koKR", function() return {
	["Tell Channel"] = "채널 전송",
	["Tell someone what Channel you are listening to"] = "듣고 있는 채널을 알려줍니다.",

	["Guild"] = "길드",
	["Tell -Guild- what you are currently playing."] = "현재 재생중인 채널을 길드에 알립니다.",	
} end)

--- ========================================================= ---
--- Register New Module
--- ========================================================= ---

MusicStreamTellChannel = MusicStream:NewModule("TellChannel")

--- ========================================================= ---
--- On Initialize
--- ========================================================= ---

function MusicStreamTellChannel:OnInitialize()
    self.db = MusicStream:AcquireDBNamespace("TellChannel")
	
	MusicStreamTellChannel.defaultDB = {
    }
	
	MusicStream:RegisterDefaults("TellChannel", "profile", opts or MusicStreamTellChannel.defaultDB or {})
    
	local bluecolor = "|cFF0099CC"
	local lbluecolor = "|cFF77BBFF"
	
    MusicStream.Options.args.TellChannel = {
        name = L["Tell Channel"],
        desc = L["Tell someone what Channel you are listening to"],
		order = 202,
        type = "group",
        args = {
			header = {
				type = "header",
				name = bluecolor..L["Tell Channel"].."  |c88888888"..Revision,
				icon = "Interface\\Addons\\MusicStream\\icon.tga",
				iconHeight = 14,
				iconWidth = 14,
				order = 1
            },
			blank = {
       			type = "header",
				order = 2,
			},
        	guild = {
            	name = string.format(L["Guild"], 1),
                desc = string.format(L["Tell -Guild- what you are currently playing."], 1),
                type = "execute",
    			func = function() MSTellWho = "Guild" self.TellChannel() end,
            },
        }
    }
end

--- ========================================================= ---
--- Reset DB
--- ========================================================= ---

local function copyTable(to, from)
	setmetatable(to, nil)
	for k,v in pairs(from) do
		if type(k) == "table" then
			k = copyTable({}, k)
		end
		if type(v) == "table" then
			v = copyTable({}, v)
		end
		to[k] = v
	end
	setmetatable(to, from)
	return to
end

function MusicStreamTellChannel:ResetDB()
	copyTable(self.db.profile, MusicStreamTellChannel.defaultDB)
end

--- ========================================================= ---
--- Tell Channel
--- ========================================================= ---

function MusicStreamTellChannel:TellChannel()
	SendChatMessage("Now Playing - "..ChannelNowLabel.." - "..ChannelNowAddress, MSTellWho, this.language);
end